@@ -142,11 +142,13 @@ void SKGAdviceBoardWidget::dataModified(bool iForce)
     m_refreshNeeded = false;
 
     // Remove all item of the layout
-    QLayoutItem* child = NULL;
-    while ((child = m_layout->takeAt(0)) != 0) {
-        QWidget* w = child->widget();
-        delete w;
-        delete child;
+    while (m_layout->count()) {
+        QLayoutItem* child = m_layout->takeAt(0);
+        if (child) {
+            QWidget* w = child->widget();
+            delete w;
+            delete child;
+        }
     }
 
     // Get list of advice
