@@ -78,15 +78,18 @@ bool SKGHighlightPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 void SKGHighlightPlugin::refresh()
 {
     SKGTRACEINFUNC(10);
-    if (m_currentDocument && SKGMainPanel::getMainPanel()) {
+    if (m_currentDocument && SKGMainPanel::getMainPanel() && m_switchHighLight) {
+        m_switchHighLight->setEnabled(false);
+
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         if (selection.count() > 0) {
-            if (m_switchHighLight) {
-                m_switchHighLight->setEnabled(selection.at(0).getAttributes().contains("t_bookmarked"));
-            }
-        } else {
-            if (m_switchHighLight) {
-                m_switchHighLight->setEnabled(false);
+            SKGServices::SKGAttributesList attributes;
+            m_currentDocument->getAttributesDescription(selection.at(0).getRealTable(), attributes);
+            foreach(const SKGServices::SKGAttributeInfo & att, attributes) {
+                if (att.name == "t_bookmarked") {
+                    m_switchHighLight->setEnabled(true);
+                    break;
+                }
             }
         }
     }
