@@ -134,9 +134,9 @@ SKGError SKGImportPluginXhb::importFile()
                         err = accountObj.setClosed(flags == "2" ||  flags == "3");
                     }
                     IFOKDO(err, accountObj.save())
-                    
+
                     // Change parent bank in case of ASSETS
-                    if(accountObj.getType() == SKGAccountObject::WALLET) {
+                    if (accountObj.getType() == SKGAccountObject::WALLET) {
                         // Get blank bank
                         SKGBankObject blankBank(m_importer->getDocument());
                         IFOKDO(err, blankBank.setName(""))
@@ -144,11 +144,11 @@ SKGError SKGImportPluginXhb::importFile()
                             err = blankBank.load();
                         } else {
                             err = blankBank.save();
-                        }                                            
+                        }
                         IFOKDO(err, accountObj.setBank(blankBank))
-                        IFOKDO(err, accountObj.save())                                      
-                    }   
-                    
+                        IFOKDO(err, accountObj.save())
+                    }
+
                     // Set initial balance
                     IFOKDO(err, accountObj.setInitialBalance(SKGServices::stringToDouble(getAttribute(account,  "initial")), unit))
 
@@ -194,8 +194,8 @@ SKGError SKGImportPluginXhb::importFile()
                         bool catCreated = false;
                         SKGCategoryObject catObj(m_importer->getDocument());
                         QString parent2 = getAttribute(category,  "parent");
-                        if(parent2.isEmpty()) {
-                            parent2 = "0";
+                        if (parent2.isEmpty()) {
+                            parent2 = '0';
                         }
                         if (parent2 == "0" && j == 0) {
                             IFOKDO(err, catObj.setName(getAttribute(category,  "name")))
