@@ -18,14 +18,13 @@
 #define SKGCALCULATORPLUGINWIDGET_H
 /** @file
  * A skrooge plugin to calculate
-*
-* @author Stephane MANKOWSKI
-*/
+ *
+ * @author Stephane MANKOWSKI
+ */
+#include <QTimer>
 #include "ui_skgcalculatorpluginwidget_base.h"
 #include "skgtabpage.h"
 
-#include <QTimer>
-
 class SKGObjectModel;
 
 /**
@@ -90,11 +89,11 @@ public:
 protected:
     /**
      * Event filtering
-     * @param object object
-     * @param event event
+     * @param iObject object
+     * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* object, QEvent* event);
+    virtual bool eventFilter(QObject* iObject, QEvent* iEvent);
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction);
@@ -118,4 +117,4 @@ private:
     QTimer m_timer;
 };
 
-#endif // SKGCALCULATORPLUGINWIDGET_H
+#endif  // SKGCALCULATORPLUGINWIDGET_H
