@@ -102,6 +102,26 @@ bool SKGCategoriesPlugin::setupActions(SKGDocument* iDocument, const QStringList
     KAction* deleteUnusedCategoriesAction = new KAction(KIcon(icon(), NULL, overlaydelete), i18nc("Verb", "Delete unused categories"), this);
     connect(deleteUnusedCategoriesAction, SIGNAL(triggered(bool)), SLOT(deleteUnusedCategories()));
     registerGlobalAction("clean_delete_unused_categories", deleteUnusedCategoriesAction);
+
+    // ------------
+    KAction* actTmp = new KAction(KIcon(icon()), i18nc("Verb", "Open similar categories..."), this);
+    actTmp->setData(QString("skg://skrooge_categories_plugin/?title_icon=" % icon() % "&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Similar categories")) %
+                            "&whereClause=" % SKGServices::encodeForUrl("id IN (SELECT category.id FROM category, ("
+                                    "SELECT * FROM category C WHERE EXISTS (SELECT 1 FROM category p2 WHERE p2.id<>C.id AND upper(p2.t_fullname)=upper(C.t_fullname) AND p2.t_fullname<>C.t_fullname)) "
+                                    "AS C WHERE category.t_fullname=C.t_fullname OR C.t_fullname LIKE category.t_fullname||' > %')")));
+    connect(actTmp, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
+    registerGlobalAction("view_open_similar_categories", actTmp);
+    /*TODO
+    WITH RECURSIVE
+    cat(t_fullname,id, level) AS (
+    SELECT t_fullname, id, 0 FROM v_category_display WHERE EXISTS (SELECT 1 FROM category p2 WHERE p2.id<>v_category_display.id AND upper(p2.t_fullname)=upper(v_category_display.t_fullname) AND p2.t_fullname<>v_category_display.t_fullname)
+    UNION ALL
+    SELECT v_category_display.name, cat.level+1
+    FROM v_category_display JOIN cat ON v_category_display.rd_category_id=under_alice.id
+    ORDER BY 2
+    )
+    SELECT substr('..........',1,level*3) || name FROM cat;
+    */
     return true;
 }
 
@@ -128,8 +148,8 @@ SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
     if (iIndex == 0)  {
         SKGHtmlBoardWidget* w = new SKGHtmlBoardWidget(m_currentBankDocument,
                 getDashboardWidgetTitle(iIndex),
-                KStandardDirs().findResource("data", "skrooge/html/default/categories_month_table.html"),
-                QStringList() << "v_operation_consolidated", true);
+                KStandardDirs().findResource("data", "skrooge/html/default/categories_period_table.html"),
+                QStringList() << "v_suboperation_consolidated", true);
 
         QStringList overlayopen;
         overlayopen.push_back("skg_open");
@@ -148,7 +168,7 @@ SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
     } else if (iIndex == 1) return new SKGHtmlBoardWidget(m_currentBankDocument,
                                        getDashboardWidgetTitle(iIndex),
                                        KStandardDirs().findResource("data", "skrooge/html/default/categories_variations.html"),
-                                       QStringList() << "v_operation_consolidated", true);
+                                       QStringList() << "v_suboperation_consolidated", true);
     return new SKGHtmlBoardWidget(m_currentBankDocument,
                                   getDashboardWidgetTitle(iIndex),
                                   KStandardDirs().findResource("data", "skrooge/html/default/budget_table.html"),
@@ -340,6 +360,23 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
             output.push_back(ad);
         }
     }
+
+    // Check categories with different case
+    if (!iIgnoredAdvice.contains("skgcategoriesplugin_case")) {
+        bool exist = false;
+        m_currentBankDocument->existObjects("category", "EXISTS (SELECT 1 FROM category p2 WHERE p2.id<>category.id AND upper(p2.t_fullname)=upper(category.t_fullname) AND p2.t_fullname<>category.t_fullname)", exist);
+        if (exist) {
+            SKGAdvice ad;
+            ad.setUUID("skgcategoriesplugin_case");
+            ad.setPriority(3);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Some categories seem to be identical"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "Some categories seem to be identical but with different syntax. They could be merged."));
+            QStringList autoCorrections;
+            autoCorrections.push_back("skg://view_open_similar_categories");
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
+    }
     return output;
 }
 
@@ -351,7 +388,7 @@ SKGError SKGCategoriesPlugin::executeAdviceCorrection(const QString& iAdviceIden
         QString month = QDate::currentDate().toString("yyyy-MM");
 
         // Call operation plugin
-        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=skrooge_category&operationTable=v_operation_consolidated&title=" %
+        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=skrooge_category&operationTable=v_suboperation_consolidated&title=" %
                                                SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub operations with category containing '%1'",  category)) % "&operationWhereClause=" % SKGServices::encodeForUrl("d_DATEMONTH='" % month % "' AND t_REALCATEGORY='" % SKGServices::stringToSqlString(category) % '\''));
         return SKGError();
     }
