@@ -335,7 +335,7 @@ void SKGImportExportPlugin::refresh()
 
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         if (selection.count() > 0 && test) {
-            bool onOperation = (selection.at(0).getRealTable() == "operation" &&  selection.at(0).getTable() != "v_operation_consolidated");
+            bool onOperation = (selection.at(0).getRealTable() == "operation");
             if (m_validateImportedOperationsAction) {
                 m_validateImportedOperationsAction->setEnabled(onOperation);
             }
