@@ -153,7 +153,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
 
     // ------------
     m_openSuboperations = new KAction(KIcon("split", NULL, overlayopen), i18nc("Verb", "Open sub operations..."), this);
-    m_openSuboperations->setData(QString("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?title_icon=split&operationTable=v_operation_consolidated&operationWhereClause=&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub operations"))));
+    m_openSuboperations->setData(QString("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?title_icon=split&operationTable=v_suboperation_consolidated&operationWhereClause=&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub operations"))));
     connect(m_openSuboperations, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
     m_openSuboperations->setShortcut(Qt::META + Qt::Key_S);
     registerGlobalAction("view_open_suboperations", m_openSuboperations);
@@ -333,7 +333,7 @@ void SKGOperationPlugin::refresh()
             m_open->setEnabled(nb > 0);
         }
         if (nb > 0) {
-            bool onOperation = (selection.at(0).getRealTable() == "operation" &&  selection.at(0).getTable() != "v_operation_consolidated");
+            bool onOperation = (selection.at(0).getRealTable() == "operation");
             if (m_duplicateAction) {
                 m_duplicateAction->setEnabled(onOperation);
             }
@@ -490,7 +490,7 @@ void SKGOperationPlugin::onApplyTemplate()
 
                     SKGOperationObject op;
                     IFOKDO(err, temp.duplicate(op))
-                    IFOKDO(err, op.mergeAttribute(operationObj, SKGOperationObject::PROPORTIONAL))
+                    IFOKDO(err, op.mergeAttribute(operationObj, SKGOperationObject::PROPORTIONAL, false))
                     listUUID.push_back(op.getUniqueID());
 
                     IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
@@ -769,7 +769,7 @@ void SKGOperationPlugin::onOpenOperations()
 
                 // Set icon
                 iconOpen = "skrooge_category";
-                view = "v_operation_consolidated";
+                view = "v_suboperation_consolidated";
             } else if (table == "refund") {
                 // Build whereclause and title
                 wc = "t_REALREFUND in (";
@@ -788,7 +788,7 @@ void SKGOperationPlugin::onOpenOperations()
 
                 // Set icon
                 iconOpen = "skrooge_tracker";
-                view = "v_operation_consolidated";
+                view = "v_suboperation_consolidated";
             } else if (table == "payee") {
                 // Build whereclause and title
                 wc = "r_payee_id in (";
@@ -823,7 +823,7 @@ void SKGOperationPlugin::onOpenOperations()
 
                 // Set icon
                 iconOpen = "view-income-categories";
-                view = "v_operation_consolidated";
+                view = "v_suboperation_consolidated";
             } else if (table == "recurrentoperation") {
                 titleOpen = i18nc("Noun, a list of items", "Scheduled operations:");
 
@@ -857,12 +857,12 @@ void SKGOperationPlugin::onOpenOperations()
 
                 // Set icon
                 iconOpen = "edit-find";
-                view = "v_operation_consolidated";
-            } else if (table == "operation") {
+                view = "v_suboperation_consolidated";
+            } else if (table == "operation" || table == "suboperation") {
                 // Build whereclause and title
-                if (selection.at(0).getTable() != "v_operation_consolidated") {
+                if (selection.at(0).getTable() != "v_suboperation_consolidated") {
                     titleOpen = i18nc("Noun, a list of items", "Sub operations grouped or split of:");
-                    view = "v_operation_consolidated";
+                    view = "v_suboperation_consolidated";
                 } else {
                     titleOpen = i18nc("Noun, a list of items", "Operations grouped with:");
                     view = "v_operation_display_all";
@@ -876,7 +876,7 @@ void SKGOperationPlugin::onOpenOperations()
                     }
 
                     int opid = tmp.getID();
-                    wc += "(id=" % SKGServices::intToString(opid);
+                    wc += QString("(") % (view == "v_suboperation_consolidated" ? "i_OPID" : "id") % "=" % SKGServices::intToString(opid);
 
                     opid = SKGServices::stringToInt(tmp.getAttribute("i_group_id"));
                     if (opid != 0) {
@@ -893,7 +893,7 @@ void SKGOperationPlugin::onOpenOperations()
 
             // Open
             QDomDocument doc("SKGML");
-            doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(view != "v_operation_consolidated" ? "SKGOPERATION_DEFAULT_PARAMETERS" : "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS"));
+            doc.setContent(SKGMainPanel::getMainPanel()->getDocument()->getParameter(view != "v_suboperation_consolidated" ? "SKGOPERATION_DEFAULT_PARAMETERS" : "SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS"));
             QDomElement root = doc.documentElement();
             if (root.isNull()) {
                 root = doc.createElement("parameters");
