@@ -24,9 +24,11 @@
 #include "skginterfaceplugin.h"
 #include "ui_skgoperationpluginwidget_pref.h"
 
+class KMenu;
 class SKGMainPanel;
 class KAction;
 class SKGDocumentBank;
+class KToolBarPopupAction;
 
 /**
  * This file is Skrooge plugin for operation management
@@ -168,6 +170,8 @@ private Q_SLOTS:
     void onAlignComment();
     void onAlignDate();
     void onRemoveGroupWithOneOperation();
+    void onShowApplyTemplateMenu();
+    void onApplyTemplate();
 
 private:
     Q_DISABLE_COPY(SKGOperationPlugin)
@@ -183,6 +187,8 @@ private:
     KAction* m_ungroupOperation;
     KAction* m_mergeOperationAction;
     KAction* m_open;
+    KToolBarPopupAction* m_applyTemplateAction;
+    KMenu* m_applyTemplateMenu;
 
     SKGDocumentBank* m_currentBankDocument;
 
