@@ -74,6 +74,13 @@ bool SKGPayeePlugin::setupActions(SKGDocument* iDocument, const QStringList& iAr
     connect(deleteUnusedPayeesAction, SIGNAL(triggered(bool)), SLOT(deleteUnusedPayees()));
     registerGlobalAction("clean_delete_unused_payees", deleteUnusedPayeesAction);
 
+    // ------------
+    KAction* actTmp = new KAction(KIcon(icon()), i18nc("Verb", "Open similar payees..."), this);
+    actTmp->setData(QString("skg://skrooge_payee_plugin/?title_icon=" % icon() % "&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Similar payees")) %
+                            "&whereClause=" % SKGServices::encodeForUrl("EXISTS (SELECT 1 FROM payee p2 WHERE p2.id<>v_payee_display.id AND upper(p2.t_name)=upper(v_payee_display.t_name) AND p2.t_name<>v_payee_display.t_name)")));
+    connect(actTmp, SIGNAL(triggered(bool)), SKGMainPanel::getMainPanel(), SLOT(openPage()));
+    registerGlobalAction("view_open_similar_payees", actTmp);
+
     return true;
 }
 
@@ -140,6 +147,23 @@ SKGAdviceList SKGPayeePlugin::advice(const QStringList& iIgnoredAdvice)
             output.push_back(ad);
         }
     }
+
+    // Check payee with different case
+    if (!iIgnoredAdvice.contains("skgpayeeplugin_case")) {
+        bool exist = false;
+        m_currentBankDocument->existObjects("payee", "EXISTS (SELECT 1 FROM payee p2 WHERE p2.id<>payee.id AND upper(p2.t_name)=upper(payee.t_name) AND p2.t_name<>payee.t_name)", exist);
+        if (exist) {
+            SKGAdvice ad;
+            ad.setUUID("skgpayeeplugin_case");
+            ad.setPriority(3);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Some payees seem to be identical"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "Some payee seem to be identical but with different syntax. They could be merged."));
+            QStringList autoCorrections;
+            autoCorrections.push_back("skg://view_open_similar_payees");
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
+    }
     return output;
 }
 
