@@ -465,7 +465,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
         }
         if (att.startsWith(QLatin1String("p_"))) {
             QString propertyName = att.right(att.length() - 2);
-            att = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_operation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
+            att = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
         }
         if (att.isEmpty()) {
             att = '\'' % i18nc("Noun", "All") % '\'';
@@ -505,7 +505,7 @@ void SKGReportPluginWidget::getWhereClauseAndTitleForSelection(int row, int colu
     }
     if (att.startsWith(QLatin1String("p_"))) {
         QString propertyName = att.right(att.length() - 2);
-        att = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_operation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
+        att = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
     }
     if (!att.isEmpty()) {
         if (column != 0 && column < nbCol) {
@@ -565,7 +565,7 @@ void SKGReportPluginWidget::onDoubleClick(int row, int column)
     QString wc;
     QString title;
     getWhereClauseAndTitleForSelection(row, column, wc, title);
-    SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=view-investment&operationTable=v_operation_consolidated&operationWhereClause=" % SKGServices::encodeForUrl(wc) % "&title=" % SKGServices::encodeForUrl(title));
+    SKGMainPanel::getMainPanel()->openPage("skg://skrooge_operation_plugin/SKGOPERATION_CONSOLIDATED_DEFAULT_PARAMETERS/?currentPage=-1&title_icon=view-investment&operationTable=v_suboperation_consolidated&operationWhereClause=" % SKGServices::encodeForUrl(wc) % "&title=" % SKGServices::encodeForUrl(title));
 }
 
 void SKGReportPluginWidget::onBtnModeClicked(int mode)
@@ -774,7 +774,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
     QSqlDatabase* db = getDocument()->getDatabase();
     setEnabled(db != NULL);
     // Check if needed
-    if (db != NULL && (iTableName == "v_operation_consolidated" || iTableName.isEmpty())) {
+    if (db != NULL && (iTableName == "v_suboperation_consolidated" || iTableName.isEmpty())) {
         SKGError err;
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
         if (doc) {
@@ -898,14 +898,14 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
 
                 // Execute sql order
                 SKGStringListList table;
-                QString tableName = "v_operation_consolidated";
+                QString tableName = "v_suboperation_consolidated";
                 QString attCol = m_attsForColumns[col ];
                 if (attCol == "#NOTHING#") {
                     attCol = "";
                 }
                 if (attCol.startsWith(QLatin1String("p_"))) {
                     QString propertyName = attCol.right(attCol.length() - 2);
-                    attCol = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_operation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
+                    attCol = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
                 }
 
                 QStringList listAtt = m_attsForLinesAdded;
@@ -921,7 +921,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     }
                     if (att.startsWith(QLatin1String("p_"))) {
                         QString propertyName = att.right(att.length() - 2);
-                        att = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_operation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
+                        att = "IFNULL((SELECT t_value FROM parameters WHERE t_uuid_parent=v_suboperation_consolidated.id||'-operation' AND t_name='" % propertyName % "'), '#NULL#')";
                     }
                     if (att.isEmpty()) {
                         att = '\'' % i18nc("Noun", "All") % '\'';
@@ -937,12 +937,12 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     tableName = "(SELECT ";
                     if (!modeHistory) {
                         tableName += "d_date, ";
-                        tableName += attCol % "||(CASE WHEN " % conditionForecast % " THEN '999' ELSE '' END) AS " % m_attsForColumns[col ] % ",* FROM v_operation_consolidated) as v_operation_consolidated";
+                        tableName += attCol % "||(CASE WHEN " % conditionForecast % " THEN '999' ELSE '' END) AS " % m_attsForColumns[col ] % ",* FROM v_suboperation_consolidated) as v_suboperation_consolidated";
                     } else {
                         if (attCol != "d_date") {
                             tableName += "(CASE WHEN (" % conditionPrevious % ") AND f_REALQUANTITY<>0 THEN '0000' ELSE d_date END) AS d_date, ";
                         }
-                        tableName += "(CASE WHEN (" % conditionPrevious % ") AND f_REALQUANTITY<>0 THEN '0000' ELSE " % attCol % "||(CASE WHEN " % conditionForecast % " THEN '999' ELSE '' END) END) AS " % m_attsForColumns[col ] % ",* FROM v_operation_consolidated) as v_operation_consolidated";
+                        tableName += "(CASE WHEN (" % conditionPrevious % ") AND f_REALQUANTITY<>0 THEN '0000' ELSE " % attCol % "||(CASE WHEN " % conditionForecast % " THEN '999' ELSE '' END) END) AS " % m_attsForColumns[col ] % ",* FROM v_suboperation_consolidated) as v_suboperation_consolidated";
                     }
                 }
 
@@ -966,7 +966,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                     } else {
                         coef = '/';
                     }
-                    coef = coef % "COALESCE((SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MAX(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % " and u2.d_date<=v_operation_consolidated.d_date)), (SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MIN(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % ")),0)";
+                    coef = coef % "COALESCE((SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MAX(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % " and u2.d_date<=v_suboperation_consolidated.d_date)), (SELECT u1.f_quantity FROM unitvalue u1 where u1.rd_unit_id=" % id % " and u1.d_date=(SELECT MIN(u2.d_date) FROM unitvalue u2 where u2.rd_unit_id=" % id % ")),0)";
                 }
 
                 IFOKDO(err, doc->getConsolidatedView(tableName, attCol, attLine, "f_REALCURRENTAMOUNT" % coef,
