@@ -87,7 +87,7 @@ void SKGScheduledPlugin::refresh()
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
 
         if (selection.count() > 0) {
-            bool onOperation = (selection.at(0).getRealTable() == "operation" &&  selection.at(0).getTable() != "v_operation_consolidated");
+            bool onOperation = (selection.at(0).getRealTable() == "operation");
             if (m_scheduleOperationAction) {
                 m_scheduleOperationAction->setEnabled(onOperation);
             }
