@@ -283,7 +283,7 @@ void SKGSearchPlugin::find()
                     elementElement.setAttribute("value", selection.at(i).getAttribute("t_name"));
                 }
                 xmlsearchcondition = doc.toString();
-            } else if (table == "operation") {
+            } else if (table == "operation" || table == "suboperation") {
                 QStringList attributeForQuery;
                 attributeForQuery << "d_date" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_ACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REALREFUND";
 
