@@ -49,6 +49,7 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
     ui.kView->getShowWidget()->addItem("search", i18nc("Noun, a search", "Search"), "edit-find", "t_action_type='S'", "", "", "", "", Qt::META + Qt::Key_S);
     ui.kView->getShowWidget()->addItem("update", i18nc("Noun, a modification", "Update"), "view-refresh", "t_action_type='U'", "", "", "", "", Qt::META + Qt::Key_U);
     ui.kView->getShowWidget()->addItem("alarm", i18nc("Noun, an alarm", "Alarm"), "dialog-warning", "t_action_type='A'", "", "", "", "", Qt::META + Qt::Key_A);
+    ui.kView->getShowWidget()->addItem("template", i18nc("Noun, a modification by applying a template", "Template"), "skrooge_template", "t_action_type='T'", "", "", "", "", Qt::META + Qt::Key_T);
     ui.kView->getShowWidget()->addSeparator();
     ui.kView->getShowWidget()->addItem("highlighted", i18nc("Adjective, an highlighted item", "Highlighted"), "bookmarks", "t_bookmarked='Y'", "", "", "", "", Qt::META + Qt::Key_H);
     ui.kView->getShowWidget()->setDefaultState("search;update;alarm;highlighted");
@@ -86,8 +87,23 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
         list.push_back(ui.kAlarmFrm);
         ui.kWidgetSelector->addButton(KIcon("dialog-warning"), i18n("Alarm"), i18n("Display the edit panel for alarm"), list);
     }
+    {
+        SKGWidgetSelector::SKGListQWidget list;
+        list.push_back(ui.kQueryGrp);
+        list.push_back(ui.kBtnFrm);
+        list.push_back(ui.kTemplateFrm);
+        ui.kWidgetSelector->addButton(KIcon("skrooge_template"), i18n("Template"), i18n("Display the edit panel for updates by templates"), list);
+    }
 
     // Fill combo boxes
+    SKGStringListList result;
+    iDocument->executeSelectSqliteOrder("SELECT id, t_displayname FROM v_operation_displayname WHERE t_template='Y' ORDER BY t_displayname", result);
+    int nb2 = result.count();
+    for (int i = 1; i < nb2; ++i) {  // Ignore header
+        QStringList r = result.at(i);
+        ui.kTemplate->addItem(r.at(1), r.at(0));
+    }
+
     QStringList attributeForQuery;
     attributeForQuery << "d_DATEOP" << "i_number" << "t_mode" << "t_PAYEE" << "t_comment" << "t_REALCOMMENT" << "t_REALCATEGORY" << "t_status" << "t_bookmarked" << "t_imported" << "t_TRANSFER" << "t_UNIT" << "t_ACCOUNT" << "t_TOACCOUNT" << "f_REALCURRENTAMOUNT" << "t_REALREFUND" << "f_BALANCE";
     QStringList attributeForUpdate;
@@ -103,8 +119,8 @@ SKGSearchPluginWidget::SKGSearchPluginWidget(SKGDocument* iDocument)
         attributeForUpdate.push_back("p_" % properties.at(i));
     }
 
-    ui.kQueryCreator->setParameters(iDocument, "v_operation_consolidated", attributeForQuery);
-    ui.kActionCreator->setParameters(iDocument, "v_operation_consolidated", attributeForUpdate, true);
+    ui.kQueryCreator->setParameters(iDocument, "v_suboperation_consolidated", attributeForQuery);
+    ui.kActionCreator->setParameters(iDocument, "v_suboperation_consolidated", attributeForUpdate, true);
 
     // Bind operation view
     ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), "v_rule_display", "1=1 ORDER BY f_sortorder", this, "", false));
@@ -349,6 +365,15 @@ void SKGSearchPluginWidget::onSelectionChanged()
             QDomElement elementElement = elementLine.firstChild().toElement();
             ui.kAlarmAmount->setValue(SKGServices::stringToDouble(elementElement.attribute("value")));
             ui.kAlarmMessage->setText(elementElement.attribute("value2"));
+        } else if (index == 3) {
+            // Set template mode
+            QDomDocument doc("SKGML");
+            doc.setContent(rule.getXMLActionDefinition());
+
+            QDomElement element = doc.documentElement();
+            QDomElement elementLine = element.firstChild().toElement();
+            QDomElement elementElement = elementLine.firstChild().toElement();
+            ui.kTemplate->setCurrentIndex(ui.kTemplate->findData(elementElement.attribute("value")));
         }
     }
 
@@ -531,7 +556,7 @@ void SKGSearchPluginWidget::open(const SKGRuleObject& iRule, OpenMode iMode)
     root.setAttribute("title_icon", "edit-find");
 
     if (iMode == TABLE) {
-        root.setAttribute("operationTable", "v_operation_consolidated");
+        root.setAttribute("operationTable", "v_suboperation_consolidated");
         root.setAttribute("currentPage", "-1");
         SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName("Skrooge operation plugin"), -1, doc.toString());
     } else {
@@ -608,6 +633,24 @@ QString SKGSearchPluginWidget::getXMLActionDefinition()
         elementElement.setAttribute("value", SKGServices::doubleToString(ui.kAlarmAmount->value()));
         elementElement.setAttribute("value2", ui.kAlarmMessage->text());
 
+        output = doc.toString();
+    } else if (ui.kWidgetSelector->getSelectedMode() == 3) {
+        // Mode template
+        QDomDocument doc("SKGML");
+        QDomElement element = doc.createElement("element");
+        doc.appendChild(element);
+
+        QDomElement elementLine = doc.createElement("element");
+        element.appendChild(elementLine);
+
+        QDomElement elementElement = doc.createElement("element");
+        elementLine.appendChild(elementElement);
+
+        elementElement.setAttribute("attribute", "id");
+        elementElement.setAttribute("operator", "APPLYTEMPLATE(#V1#)");
+        elementElement.setAttribute("value", ui.kTemplate->itemData(ui.kTemplate->currentIndex()).toString());
+        elementElement.setAttribute("value2", ui.kTemplate->currentText());
+
         output = doc.toString();
     }
     return output;
