@@ -28,6 +28,7 @@
 #include <KGenericFactory>
 #include <KStandardDirs>
 #include <KComponentData>
+#include <QProcess>
 
 #include "skgunitpluginwidget.h"
 #include "skgunitboardwidget.h"
@@ -368,6 +369,27 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
+    // Check unit too complex
+    if (!iIgnoredAdvice.contains("skgunitplugin_amountnotdefined")) {
+        m_currentBankDocument->executeSelectSqliteOrder("SELECT t_name FROM v_unit WHERE t_type IN ('2','C') AND f_CURRENTAMOUNT=1", result);
+        nb = result.count();
+        for (int i = 1; i < nb; ++i) {  // Ignore header
+            // Get parameters
+            QStringList line = result.at(i);
+            QString unit = line.at(0);
+
+            SKGAdvice ad;
+            ad.setUUID("skgunitplugin_amountnotdefined|" % unit);
+            ad.setPriority(9);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "The amount of the unit '%1' is not defined", unit));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "'%1' has an amount defined at 1. Most of the time this is not normal and causes wrong computation. Check if this is normal.", unit));
+            QStringList autoCorrections;
+            autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit units"));
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
+    }
+
     // Check unit too complex
     if (!iIgnoredAdvice.contains("skgunitplugin_toocomplex")) {
         m_currentBankDocument->executeSelectSqliteOrder("SELECT A.t_name FROM unit A, unit B, unit C, unit D WHERE A.rd_unit_id=B.id AND B.rd_unit_id=C.id AND C.rd_unit_id=D.id", result);
@@ -410,6 +432,19 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
         }
     }
 
+    // No decimal settings
+    if (!iIgnoredAdvice.contains("skgunitplugin_decimalsymbol") && KGlobal::locale()->monetaryDecimalSymbol().isEmpty()) {
+        SKGAdvice ad;
+        ad.setUUID("skgunitplugin_decimalsymbol");
+        ad.setPriority(9);
+        ad.setShortMessage(i18nc("Advice on making the best (short)", "No decimal symbol defined"));
+        ad.setLongMessage(i18nc("Advice on making the best (long)", "In KDE localization settings, there is no decimal symbol defined for currencies. This could be confusing."));
+        QStringList autoCorrections;
+        autoCorrections.push_back(i18nc("Advice on making the best (action)", "Edit KDE settings"));
+        ad.setAutoCorrections(autoCorrections);
+        output.push_back(ad);
+    }
+
     return output;
 }
 
@@ -495,6 +530,12 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
     } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_toocomplex"))) {
         SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
         return SKGError();
+    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_amountnotdefined|"))) {
+        SKGMainPanel::getMainPanel()->openPage("skg://skrooge_unit_plugin");
+        return SKGError();
+    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_decimalsymbol"))) {
+        QProcess::execute("kcmshell4", QStringList() << "language");
+        return SKGError();
     }
     return SKGInterfacePlugin::executeAdviceCorrection(iAdviceIdentifier, iSolution);
 }
