@@ -21,6 +21,8 @@
  */
 #include "skgobjectmodel.h"
 
+#include <math.h>
+
 #include <KIcon>
 #include <KStandardDirs>
 #include <KLocalizedString>
@@ -80,14 +82,14 @@ SKGObjectModel(SKGDocumentBank* iDocument,
 void SKGObjectModel::buidCache()
 {
     SKGObjectModelBase::buidCache();
-    m_operationTable = (getRealTable() == "operation");
+    m_operationTable = (getRealTable() == "operation" || getRealTable() == "suboperation");
     m_payeeTable = (getRealTable() == "payee");
     m_trackerTable = (getRealTable() == "refund");
     m_recurrentoperationTable = (getRealTable() == "recurrentoperation");
     m_accountTable = (getRealTable() == "account");
     m_unitTable = (getRealTable() == "unit");
     m_unitvalueTable = (getRealTable() == "unitvalue");
-    m_suboperationTable = (getTable() == "v_operation_consolidated");
+    m_suboperationTable = (getTable() == "v_suboperation_consolidated");
     m_ruleTable = (getRealTable() == "rule");
     m_categoryTable = (getRealTable() == "category");
     m_interestTable = (getRealTable() == "interest");
@@ -180,6 +182,7 @@ void SKGObjectModel::buidCache()
         m_iconSearch = KIcon("edit-find");
         m_iconUpdate = KIcon("view-refresh");
         m_iconAlarm = KIcon("dialog-warning");
+        m_iconTemplate = KIcon("skrooge_template");
     }
     m_iconClosed = KIcon("dialog-close");
 
@@ -441,6 +444,8 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                     return m_iconSearch;
                 } else if (val == "U") {
                     return m_iconUpdate;
+                } else if (val == "T") {
+                    return m_iconTemplate;
                 } else {
                     return m_iconAlarm;
                 }
@@ -646,29 +651,59 @@ QVariant SKGObjectModel::data(const QModelIndex& iIndex, int iRole) const
                 }
             }
 
-            // Add original amount
-            QString originalAmount = obj->getProperty("SKG_OP_ORIGINAL_AMOUNT");
-            if (!originalAmount.isEmpty()) {
-                if (!toolTipString.isEmpty()) {
-                    toolTipString += "\n\n";
-                }
-                double val1 = SKGServices::stringToDouble(obj->getAttribute("f_CURRENTAMOUNT"));
-                double val2 = SKGServices::stringToDouble(originalAmount);
-                double gain = (val2 != 0 ? 100.0 * (val1 - val2) / val2 : 0);
-                SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
-                toolTipString += i18nc("Noun", "Original amount=%1 (%2 %)",
-                                       KGlobal::locale()->formatMoney(val2, primaryUnit.Symbol, primaryUnit.NbDecimal),
-                                       gain);
-            }
-
             // Add balance
             if (m_operationTable) {
                 SKGOperationObject op(*obj);
                 if (!op.isTemplate()) {
-                    if (!toolTipString.isEmpty()) {
-                        toolTipString += "\n\n";
-                    }
                     SKGServices::SKGUnitInfo primaryUnit = static_cast<SKGDocumentBank*>(getDocument())->getPrimaryUnit();
+
+                    // Add original amount
+                    QString originalAmount = obj->getProperty("SKG_OP_ORIGINAL_AMOUNT");
+                    if (!originalAmount.isEmpty()) {
+                        if (!toolTipString.isEmpty()) {
+                            toolTipString += "\n\n";
+                        }
+                        double val1 = SKGServices::stringToDouble(obj->getAttribute("f_CURRENTAMOUNT"));
+                        double val2 = SKGServices::stringToDouble(originalAmount);
+                        double gain = (val2 != 0 ? 100.0 * (val1 - val2) / val2 : 0);
+                        double gainperyear = gain;
+
+                        int nbDays = op.getDate().daysTo(QDate::currentDate());
+                        if (nbDays != 0 && val2 != 0) {
+                            double gainperday = 100 * (exp(log(val1 / val2) / nbDays) - 1);
+                            gainperyear = 100 * (pow(1 + gainperday / 100, 365) - 1);
+                        }
+                        toolTipString += i18nc("Noun", "Original amount=%1 (%2 = %3 / year)",
+                                               KGlobal::locale()->formatMoney(val2, primaryUnit.Symbol, primaryUnit.NbDecimal),
+                                               (gain >= 0 ? "+" : "-") % KGlobal::locale()->formatMoney(gain, "%", 2),
+                                               (gainperyear >= 0 ? "+" : "-") % KGlobal::locale()->formatMoney(gainperyear, "%", 2));
+                    } else {
+
+                        if (!toolTipString.isEmpty()) {
+                            toolTipString += "\n\n";
+                        }
+                        double val1 = SKGServices::stringToDouble(obj->getAttribute("f_CURRENTAMOUNT"));
+                        double val2 = op.getAmount(op.getDate());
+                        double gain = (val2 != 0 ? 100.0 * (val1 - val2) / val2 : 0);
+                        double gainperyear = gain;
+
+                        int nbDays = op.getDate().daysTo(QDate::currentDate());
+                        if (nbDays != 0 && val2 != 0) {
+                            double gainperday = 100 * (exp(log(val1 / val2) / nbDays) - 1);
+                            gainperyear = 100 * (pow(1 + gainperday / 100, 365) - 1);
+                        }
+
+                        QString sval1 = KGlobal::locale()->formatMoney(val1, primaryUnit.Symbol, primaryUnit.NbDecimal);
+                        QString sval2 = KGlobal::locale()->formatMoney(val2, primaryUnit.Symbol, primaryUnit.NbDecimal);
+                        if (sval1 != sval2) {
+                            toolTipString += i18nc("Noun", "Amount at creation date=%1 (%2 = %3 / year)",
+                                                   sval2,
+                                                   (gain >= 0 ? "+" : "-") % KGlobal::locale()->formatMoney(gain, "%", 2),
+                                                   (gainperyear >= 0 ? "+" : "-") % KGlobal::locale()->formatMoney(gainperyear, "%", 2));
+
+                            toolTipString += '\n';
+                        }
+                    }
                     toolTipString += i18nc("Noun", "Account balance=%1",
                                            KGlobal::locale()->formatMoney(op.getBalance(), primaryUnit.Symbol, primaryUnit.NbDecimal));
                 }
