@@ -302,7 +302,7 @@ SKGError SKGImportExportManager::finalizeImportation()
             int nbOperations2;
             err = m_document->getNbObjects("operation", wc2, nbOperations2);
             if (!err && nbOperations2) {
-                err = m_document->sendMessage(i18np("One operation not imported because before the last imported one, you can uncheck the option to avoid this", "%1 operations not imported because before the last imported one, you can uncheck the option to avoid this", nbOperations2), SKGDocument::Warning);
+                err = m_document->sendMessage(i18np("One operation was not imported because it was dated before the last imported one, you can uncheck the option to avoid this.", "%1 operations were not imported because they were dated before the last imported one, you can uncheck the option to avoid this.", nbOperations2), SKGDocument::Warning);
 
                 // Remove operations imported for nothing
                 IFOKDO(err, m_document->executeSqliteOrder("DELETE from operation WHERE " % wc2))
@@ -688,7 +688,7 @@ SKGError SKGImportExportManager::anonymize()
     return err;
 }
 
-SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged, bool iOnCurrentlyImport)
+SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged, const QString& iAdditionnalCondition)
 {
     SKGError err;
     SKGTRACEINFUNCRC(2, err);
@@ -709,7 +709,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
             SKGStringListList listTmp;
             IFOKDO(err, m_document->executeSelectSqliteOrder(
                        "SELECT A.id, B.id FROM v_operation_tmp1 A, v_operation_tmp1 B WHERE +A.d_date=B.d_date AND A.rc_unit_id=B.rc_unit_id AND A.id<=B.id AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_QUANTITY+B.f_QUANTITY)<" % SKGServices::doubleToString(EPSILON) % " AND A.i_group_id=0 AND B.i_group_id=0 AND A.f_QUANTITY!=0" %
-                       (iOnCurrentlyImport ? " AND A.t_imported='T' AND B.t_imported='T'" : ""),
+                       (iAdditionnalCondition.isEmpty() ? QString() : QString(" AND ") % iAdditionnalCondition),
                        listTmp));
             // Step 1 done
             IFOKDO(err, m_document->stepForward(1))
@@ -718,7 +718,7 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
             // +A.i_group_id=0 AND +B.i_group_id=0 is for avoiding to use bad index
             IFOKDO(err, m_document->executeSelectSqliteOrder(
                        "SELECT A.id, B.id FROM v_operation A, v_operation_tmp1 B, parameters P WHERE +P.t_uuid_parent=B.id||'-operation' AND A.rc_unit_id!=B.rc_unit_id AND P.t_name='SKG_OP_ORIGINAL_AMOUNT' AND A.d_date=B.d_date AND A.rd_account_id!=B.rd_account_id AND ABS(A.f_CURRENTAMOUNT+CAST(P.t_value AS REAL))<" % SKGServices::doubleToString(EPSILON) % " AND +A.i_group_id=0 AND +B.i_group_id=0 AND A.f_CURRENTAMOUNT!=0" %
-                       (iOnCurrentlyImport ? " AND A.t_imported='T' AND B.t_imported='T'" : ""),
+                       (iAdditionnalCondition.isEmpty() ? QString() : QString(" AND ") % iAdditionnalCondition),
                        listTmp2));
 
             // Step 2 done
@@ -753,4 +753,9 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
     return err;
 }
 
+SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged, bool iOnCurrentlyImport)
+{
+    return findAndGroupTransfers(oNbOperationsMerged, QString(iOnCurrentlyImport ? "A.t_imported='T' AND B.t_imported='T'" : ""));
+}
+
 #include "skgimportexportmanager.moc"
