@@ -173,6 +173,15 @@ public:
      */
     virtual SKGError anonymize();
 
+    /**
+     * Find and group operations
+     * @param oNbOperationsMerged returns the number of operations merged.
+     * @param iAdditionnalCondition a condition on operations to check (eg. A.t_imported='T' AND B.t_imported='T'")
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    virtual SKGError findAndGroupTransfers(int& oNbOperationsMerged, const QString& iAdditionnalCondition);
+
     /**
      * Find and group operations
      * @param oNbOperationsMerged returns the number of operations merged.
