@@ -26,6 +26,7 @@
 #include <QDomDocument>
 
 #include "skgunitvalueobject.h"
+#include "skgoperationobject.h"
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
 
@@ -87,7 +88,7 @@ SKGError SKGRuleObject::save(bool iInsertOrUpdate, bool iReloadAfterSave)
 
 SKGError SKGRuleObject::setXMLSearchDefinition(const QString& iXml)
 {
-    setSearchDescription(SKGRuleObject::getDescriptionFromXML(static_cast<SKGDocument*>(getDocument()), iXml, false, SEARCH));
+    setSearchDescription(SKGRuleObject::getDescriptionFromXML(getDocument(), iXml, false, SEARCH));
     return setAttribute("t_definition", iXml);
 }
 
@@ -98,7 +99,7 @@ QString SKGRuleObject::getXMLSearchDefinition() const
 
 SKGError SKGRuleObject::setXMLActionDefinition(const QString& iXml)
 {
-    setActionDescription(SKGRuleObject::getDescriptionFromXML(static_cast<SKGDocument*>(getDocument()), iXml, false, getActionType()));
+    setActionDescription(SKGRuleObject::getDescriptionFromXML(getDocument(), iXml, false, getActionType()));
     return setAttribute("t_action_definition", iXml);
 }
 
@@ -129,14 +130,14 @@ QString SKGRuleObject::getActionDescription() const
 
 SKGError SKGRuleObject::setActionType(SKGRuleObject::ActionType iType)
 {
-    SKGError err = setAttribute("t_action_type", (iType == SEARCH ? "S" : (iType == UPDATE ? "U" : "A")));
+    SKGError err = setAttribute("t_action_type", (iType == SEARCH ? "S" : (iType == UPDATE ? "U" : (iType == APPLYTEMPLATE ? "T" : "A"))));
     return err;
 }
 
 SKGRuleObject::ActionType SKGRuleObject::getActionType() const
 {
     QString typeString = getAttribute("t_action_type");
-    return (typeString == "S" ? SEARCH : (typeString == "U" ? UPDATE : ALARM));
+    return (typeString == "S" ? SEARCH : (typeString == "U" ? UPDATE : (typeString == "T" ? APPLYTEMPLATE : ALARM)));
 }
 
 SKGError SKGRuleObject::setOrder(double iOrder)
@@ -158,7 +159,7 @@ SKGError SKGRuleObject::setOrder(double iOrder)
 QString SKGRuleObject::getSelectSqlOrder(const QString& iAdditionalCondition) const
 {
     QString wc = iAdditionalCondition;
-    QString wc2 = SKGRuleObject::getDescriptionFromXML(static_cast<SKGDocument*>(getDocument()), getXMLSearchDefinition(), true, SEARCH);
+    QString wc2 = SKGRuleObject::getDescriptionFromXML(getDocument(), getXMLSearchDefinition(), true, SEARCH);
     if (!wc2.isEmpty()) {
         if (wc.isEmpty()) {
             wc = wc2;
@@ -184,7 +185,7 @@ SKGRuleObject::SKGAlarmInfo SKGRuleObject::getAlarmInfo() const
             wc = "1=1";
         }
 
-        SKGDocument* doc = static_cast<SKGDocument*>(getDocument());
+        SKGDocument* doc = getDocument();
 
         QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, ALARM, false);
         if (list.count()) {
@@ -224,7 +225,7 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
             wc = "1=1";
         }
 
-        SKGDocument* doc = static_cast<SKGDocument*>(getDocument());
+        SKGDocument* doc = getDocument();
         if (doc) {
             QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, UPDATE, true);  // SQL + SET clause
             int nb = list.count();
@@ -265,7 +266,7 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
             wc = "1=1";
         }
 
-        SKGDocument* doc = static_cast<SKGDocument*>(getDocument());
+        SKGDocument* doc = getDocument();
         if (doc) {
             QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, ALARM, false);
             if (list.count()) {
@@ -282,6 +283,35 @@ SKGError SKGRuleObject::execute(ProcessMode iMode)
                 }
             }
         }
+    } else if (getActionType() == SKGRuleObject::APPLYTEMPLATE) {
+        // Template mode
+        QString wc = getSelectSqlOrder();
+        if (wc.isEmpty()) {
+            wc = "1=1";
+        }
+
+        SKGDocument* doc = getDocument();
+        if (doc) {
+            QStringList list = SKGRuleObject::getFromXML(doc, getXMLActionDefinition(), true, APPLYTEMPLATE, false);
+            if (list.count()) {
+                QString id = list.at(0);
+
+                // Get template
+                SKGOperationObject templateToApply(doc, SKGServices::stringToInt(id));
+
+                // Get operations to modify
+                SKGObjectBase::SKGListSKGObjectBase objectsToModify;
+                IFOKDO(err, doc->getObjects("v_operation", wc, objectsToModify))
+                int nb = objectsToModify.count();
+                for (int i = 0; !err && i < nb; ++i) {
+                    SKGOperationObject operationObj(objectsToModify.at(i));
+
+                    SKGOperationObject op;
+                    IFOKDO(err, templateToApply.duplicate(op))
+                    IFOKDO(err, op.mergeAttribute(operationObj, SKGOperationObject::PROPORTIONAL, false))
+                }
+            }
+        }
     }
     IFKO(err) err.addError(ERR_FAIL, i18nc("Error message", "Rule %1 failed", getAttribute("i_ORDER")));
     return err;
@@ -401,6 +431,8 @@ QString SKGRuleObject::getDisplayForOperator(const QString& iOperator, const QSt
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "is in last 5 years");
     } else if (output == "ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'") {
         output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "If total(#ATT#)#OP##V1# then send '#V2S#'").replace("#V1#", iParam1).replace("#V2S#", iParam2).replace("#OP#", iAtt2);
+    } else if (output == "APPLYTEMPLATE(#V1#)") {
+        output = i18nc("Description of a condition. Do not translate key words (#V1S#, #V1#, ...)", "Apply the template '#V2S#'").replace("#V2S#", iParam2);
     }
 
     return output;
@@ -494,6 +526,8 @@ QStringList SKGRuleObject::getListOfOperators(SKGServices::AttributeType iAttrib
         }
     } else if (iType == ALARM) {
         output.push_back("ABS(TOTAL(#ATT#))#OP##V1#,ABS(TOTAL(#ATT#)), #V1#, '#V2S#'");
+    } else if (iType == APPLYTEMPLATE) {
+        output.push_back("APPLYTEMPLATE(#V1#)");
     }
     return output;
 }
@@ -552,7 +586,7 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                             attribute = iDocument->getDisplay(attribute);
                         }
 
-                        if (iType != ALARM) {
+                        if (iType != ALARM && iType != APPLYTEMPLATE) {
                             elementDescription = attribute;
                             elementDescription += ' ';
                         }
@@ -636,7 +670,9 @@ QStringList SKGRuleObject::getFromXML(SKGDocument* iDocument, const QString& iXM
                                 }
                             }
                         } else if (iType == ALARM) {
-                            output.push_back("SELECT " % elementDescription % " FROM v_operation_consolidated WHERE #WC#");
+                            output.push_back("SELECT " % elementDescription % " FROM v_suboperation_consolidated WHERE #WC#");
+                        } else if (iType == APPLYTEMPLATE) {
+                            output.push_back(element.attribute("value"));
                         }
                     }
 
