@@ -31,6 +31,10 @@ SKGFilteredTableView::SKGFilteredTableView(QWidget* iParent)
     : QWidget(iParent), m_objectModel(NULL), m_refreshNeeded(true)
 {
     ui.setupUi(this);
+    ui.kTitle->hide();
+    ui.kResetInternalFilter->hide();
+    connect(ui.kResetInternalFilter, SIGNAL(clicked()), this, SLOT(resetFilter()));
+    ui.kResetInternalFilter->setIcon(KIcon("dialog-cancel"));
     ui.kConfigure->setIcon(KIcon("configure"));
     ui.kConfigure->setPopupMode(QToolButton::InstantPopup);
     ui.kConfigure->setAutoRaise(true);
@@ -160,5 +164,31 @@ void SKGFilteredTableView::setModel(SKGObjectModelBase* iModel)
     dataModified("", 0);
 }
 
+void SKGFilteredTableView::resetFilter()
+{
+    getShowWidget()->setEnabled(true);
+    ui.kTitle->hide();
+    ui.kResetInternalFilter->hide();
+
+    m_objectModel->setFilter("");
+    m_objectModel->refresh();
+}
+
+void SKGFilteredTableView::setFilter(const KIcon& iIcon, const QString& iText, const QString& iWhereClause)
+{
+    if (m_objectModel && !iWhereClause.isEmpty()) {
+        getShowWidget()->setEnabled(false);
+
+        ui.kTitle->setComment("<html><body><b>" % SKGServices::stringToHtml(iText) % "</b></body></html>");
+        ui.kTitle->show();
+        ui.kResetInternalFilter->show();
+
+        ui.kTitle->setPixmap(KIcon(iIcon).pixmap(22, 22), KTitleWidget::ImageLeft);
+
+        m_objectModel->setFilter(iWhereClause);
+        m_objectModel->refresh();
+    }
+}
+
 #include "skgfilteredtableview.moc"
 
