@@ -54,6 +54,7 @@ SKGPeriodEdit::SKGPeriodEdit(QWidget* iParent)
     connect(ui.kDateEnd, SIGNAL(dateEntered(QDate)), this, SLOT(refresh()));
     connect(ui.kNbIntervals, SIGNAL(valueChanged(int)), this, SLOT(refresh()));
     connect(ui.kTimeline, SIGNAL(valueChanged(int)), this, SLOT(refresh()));
+    connect(ui.kFuture, SIGNAL(stateChanged(int)), this, SLOT(refresh()));
 }
 
 SKGPeriodEdit::~SKGPeriodEdit()
@@ -74,6 +75,7 @@ QString SKGPeriodEdit::getState()
     root.setAttribute("interval", SKGServices::intToString(ui.kInterval->itemData(ui.kInterval->currentIndex()).toInt()));
     root.setAttribute("nb_intervals", SKGServices::intToString(ui.kNbIntervals->value()));
     root.setAttribute("timeline", SKGServices::intToString(ui.kTimeline->value()));
+    root.setAttribute("future", ui.kFuture->isChecked() ? "Y" : "N");
 
     return doc.toString();
 }
@@ -92,6 +94,7 @@ void SKGPeriodEdit::setState(const QString& iState)
     QString timeline = root.attribute("timeline");
     QString date_begin = root.attribute("date_begin");
     QString date_end = root.attribute("date_end");
+    QString future = root.attribute("future");
 
     // Default values
     if (period.isEmpty()) {
@@ -110,6 +113,7 @@ void SKGPeriodEdit::setState(const QString& iState)
     ui.kInterval->setCurrentIndex(ui.kInterval->findData(SKGServices::stringToInt(interval)));
     ui.kTimeline->setValue(SKGServices::stringToInt(timeline));
     ui.kNbIntervals->setValue(SKGServices::stringToInt(nb_interval));
+    ui.kFuture->setChecked(future == "Y");
     if (!date_begin.isEmpty()) {
         ui.kDateBegin->setDate(QDate::fromJulianDay(SKGServices::stringToInt(date_begin)));
     }
@@ -228,9 +232,16 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
             b = a.addMonths(6).addDays(-1);
             break;
         }
+        if (ui.kFuture->isChecked()) {
+            b = QDate(2099, 12, 31);
+        }
+
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
         wc = "period(d_date, " % strfFormat % ") = (SELECT period(date('now'), " % strfFormat % "))";
+        if (ui.kFuture->isChecked()) {
+            wc +=  " OR d_date > (SELECT date('now'))";
+        }
         if (oWhereClausForPreviousData) {
             *oWhereClausForPreviousData = "period(d_date, " % strfFormat % ") < (SELECT period(date('now'), " % strfFormat % "))";
         }
@@ -273,54 +284,64 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
             a = b.addDays(1).addMonths(-val);
             break;
         }
+
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
         wc = "period(d_date, " % strfFormat % ")>=(SELECT period(date('now','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
         if (iForecast) {
             wc += " AND period(d_date, " % strfFormat % ")<=(SELECT period(date('now','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";    // For forecast based on scheduled operations
+
+            if (oWhereClausForPreviousData) {
+                *oWhereClausForPreviousData = "period(d_date, " % strfFormat % ") < (SELECT period(date('now','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
+            }
+            if (oWhereClausForForecastData) {
+                *oWhereClausForForecastData = "period(d_date, " % strfFormat % ") > (SELECT period(date('now','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";
+            }
+            break;
+        case LAST:
+            // Last Interval
+            switch (ui.kInterval->itemData(ui.kInterval->currentIndex()).toInt()) {
+            case 0:
+                // Interval is in days
+                a = a.addDays(-val);
+                break;
+            case 1:
+                // Interval is in weeks
+                a = a.addDays(-val);
+                break;
+            case 2:
+            default:
+                // Interval is in months
+                a = a.addMonths(-val);
+                break;
+            case 3:
+                // Interval is in years
+                a = a.addYears(-val);
+                break;
+            case 4:
+                // Interval is in quarter
+                a = a.addMonths(-val);
+                break;
+            case 5:
+                // Interval is in semester
+                a = a.addMonths(-val);
+                break;
+            }
+            a = a.addDays(1);
+            if (ui.kFuture->isChecked()) {
+                b = QDate(2099, 12, 31);
+            }
+
+            ui.kDateBegin->setDate(a);
+            ui.kDateEnd->setDate(b);
+
+            wc = "d_date > (SELECT date('now','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
+            if (iForecast) {
+                wc += " AND d_date<=(SELECT date('now'))";    // For forecast based on scheduled operations
+            }
         }
-        if (oWhereClausForPreviousData) {
-            *oWhereClausForPreviousData = "period(d_date, " % strfFormat % ") < (SELECT period(date('now','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
-        }
-        if (oWhereClausForForecastData) {
-            *oWhereClausForForecastData = "period(d_date, " % strfFormat % ") > (SELECT period(date('now','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";
-        }
-        break;
-    case LAST:
-        // Last Interval
-        switch (ui.kInterval->itemData(ui.kInterval->currentIndex()).toInt()) {
-        case 0:
-            // Interval is in days
-            a = a.addDays(-val);
-            break;
-        case 1:
-            // Interval is in weeks
-            a = a.addDays(-val);
-            break;
-        case 2:
-        default:
-            // Interval is in months
-            a = a.addMonths(-val);
-            break;
-        case 3:
-            // Interval is in years
-            a = a.addYears(-val);
-            break;
-        case 4:
-            // Interval is in quarter
-            a = a.addMonths(-val);
-            break;
-        case 5:
-            // Interval is in semester
-            a = a.addMonths(-val);
-            break;
-        }
-        a = a.addDays(1);
-        ui.kDateBegin->setDate(a);
-        ui.kDateEnd->setDate(b);
-        wc = "d_date > (SELECT date('now','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
-        if (iForecast) {
-            wc += " AND d_date<=(SELECT date('now'))";    // For forecast based on scheduled operations
+        if (ui.kFuture->isChecked()) {
+            wc += " OR d_date > (SELECT date('now'))";
         }
         if (oWhereClausForPreviousData) {
             *oWhereClausForPreviousData = "d_date <= (SELECT date('now','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
@@ -422,6 +443,7 @@ void SKGPeriodEdit::refresh()
     ui.kDateSelect->setVisible(p != ALL);
     ui.kDateSelect->setEnabled(p == CUSTOM);
     ui.kTimeline->setVisible(p == TIMELINE);
+    ui.kFuture->setVisible(p == CURRENT || p == LAST);
 
     QDate d1 = ui.kDateBegin->date();
     QDate d2 = ui.kDateEnd->date();
