@@ -349,6 +349,12 @@ public Q_SLOTS:
      */
     virtual bool switchLimitsVisibility();
 
+    /**
+     * Switch the average visibility
+     * @return the new visibility
+     */
+    virtual bool switchAverageVisibility();
+
     /**
      * Switch the linear regression visibility
      * @return the new visibility
@@ -437,6 +443,7 @@ private:
     bool m_toolBarVisible;
     bool m_graphTypeVisible;
     bool m_limitVisible;
+    bool m_averageVisible;
     bool m_linearRegressionVisible;
     bool m_paretoVisible;
     bool m_legendVisible;
@@ -450,6 +457,7 @@ private:
     QTimer m_timer;
     QTimer m_timerRedraw;
     QAction* m_actShowLimits;
+    QAction* m_actShowAverage;
     QAction* m_actShowLinearRegression;
     QAction* m_actShowPareto;
     QAction* m_actShowLegend;
