@@ -252,6 +252,20 @@ public:
      */
     static QString timeToString(const QDateTime& iDateTime);
 
+    /**
+     * Convert a date in a period
+     * @param iDate the time
+     * @param iPeriod the period.
+     * D for day, example: 2013-05-21
+     * W for week, example: 2013-W10
+     * M for month, example: 2013-05
+     * Q for quarter, example: 2013-Q2
+     * S for semester, example: 2013-S1
+     * Y for year, example: 2013
+     * @return the period string
+     */
+    static QString dateToPeriod(const QDate& iDate, const QString& iPeriod);
+
     /**
      * Compute the number of working days between two dates.
      * @param iFrom first date
@@ -275,6 +289,14 @@ public:
      */
     static QString dateToSqlString(const QDateTime& iDateTime);
 
+    /**
+     * Convert a QDateTime into a QString ready for sql order.
+     * The output format is "%Y-%m-%d"
+     * @param iDateTime the time
+     * @return the converted QString
+     */
+    static QString dateToSqlString(const QDate& iDateTime);
+
     /**
      * Format a date.
      * The output format is "YYYY-MM-DD"
@@ -283,10 +305,34 @@ public:
      * "YYYYMMDD","DDMMYYYY", "MMDDYYYY" "YYYY-MM-DD"
      * "MM/DD/YY", "MM-DD-YY", "DD/MM/YY", "DD-MM-YY"
      * "MM/DD/YYYY", "MM-DD-YYYY", "DD/MM/YYYY", "DD-MM-YYYY"
+     * "DD/MMM/YY" "DD-MMM-YY" DDMMMYY
+     * "DD/MMM/YYYY" "DD-MMM-YYYY" DDMMMYYYY
      * @return the converted QString
      */
     static QString dateToSqlString(const QString& iDate, const QString& iFormat);
 
+    /**
+     * Get the sql where clause corresponding to a a period date.
+     * @param iPeriod the period date (some thing like 2014 or 2014-04 or 2014-Q2 or 2014-S2
+     * @param iDateAttribute the date attribute
+     * @return the where clause
+     */
+    static QString getPeriodWhereClause(const QString& iPeriod, const QString& iDateAttribute = "d_date");
+
+    /**
+     * Get the last date of a period.
+     * @param iPeriod the period date
+     * @return the last date
+     */
+    static QDate periodToDate(const QString& iPeriod);
+
+    /**
+     * Get the previous period.
+     * @param iPeriod the period date (some thing like 2014 or 2014-04 or 2014-Q2 or 2014-S2
+     * @return the previous period
+     */
+    static QString getPerviousPeriod(const QString& iPeriod);
+
     /**
      * Get the format of a list of string dates
      * @param iDates a list of string dates
@@ -388,6 +434,16 @@ public:
     */
     static SKGError executeSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, SKGStringListList& oResult);
 
+    /**
+     * Execute a select sqlite order returning one value and return the result in @p oResult
+     * @param iDb A database pointer
+     * @param iSqlOrder the sql order
+     * @param oResult the result of the select
+     * @return An object managing the error
+     *   @see SKGError
+     */
+    static SKGError executeSingleSelectSqliteOrder(QSqlDatabase* iDb, const QString& iSqlOrder, QString& oResult);
+
     /**
     * dump a select sqlite order
     * @param iDb A database pointer
